@@ -20,3 +20,10 @@ async def create_exchange_transform(exchange_transform: ExchangeTransform):
     exchange_transform_repository = ItemHolder.get_entity(ExchangeTransformRepository)
     exchange_transform_repository.append(exchange_transform)
     return exchange_transform
+
+
+@router.delete('/transform/exchange')
+async def delete_exchange_transform(exchange_transform: ExchangeTransform):
+    exchange_transform_repository = ItemHolder.get_entity(ExchangeTransformRepository)
+    exchange_transform_repository.remove(exchange_transform)
+    return exchange_transform
